declare const _default: import("vue").DefineComponent<{
    assetId: {
        type: StringConstructor;
        required: boolean;
    };
    projectId: {
        type: StringConstructor;
        default: null;
    };
    dataset: {
        type: StringConstructor;
        default: null;
    };
    /**
       * Set auto=format to automatically return an image in webp formatting if the browser supports it.
       */
    auto: {
        type: StringConstructor;
    };
    /**
       * Fill in any transparent areas in the image with a color. The string must be resolve to a valid hexadecimal color (RGB, ARGB, RRGGBB, or AARRGGBB). E.g. bg=ff00 for red background with no transparency.
       */
    bg: {
        type: StringConstructor;
    };
    /**
       * Blur 0-100.
       */
    blur: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: string | number) => boolean;
    };
    /**
         * Use with fit=crop to specify how cropping is performed:
            - top, bottom, left and right: The crop starts from the edge specified. crop=top,left will crop the image starting in the top left corner.
            - center: Will crop around the center of the image
            - focalpoint: Will crop around the focal point specified using the fp-x and fp-y parameters.
            - entropy: Attempts to preserve the "most important" part of the image by selecting the crop that preserves the most complex part of the image.
         */
    crop: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Configures the headers so that opening this link causes the browser to download the image rather than showing it. The browser will suggest to use the file name you provided.
       */
    dl: {
        type: StringConstructor;
    };
    /**
       * Specifies device pixel ratio scaling factor. From 1 to 3.
       */
    dpr: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
         * Affects how the image is handled when you specify target dimensions.
            - `clip`: The image is resized to fit within the bounds you specified without cropping or distorting the image.
            - `crop`: Crops the image to fill the size you specified when you specify both w and h
            - `fill`: Like clip, but the any free area not covered by your image is filled with the color specified in the bg parameter.
            - `fillmax`: Places the image within box you specify, never scaling the image up. If there is excess room in the image, it is filled with the color specified in the bg parameter.
            - `max`: Fit the image within the box you specify, but never scaling the image up.
            - `scale`: Scales the image to fit the constraining dimensions exactly. The resulting image will fill the dimensions, and will not maintain the aspect ratio of the input image.
            - `min`: Resizes and crops the image to match the aspect ratio of the requested width and height. Will not exceed the original width and height of the image.
         */
    fit: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Flipping. Flip image horizontally, vertically or both. Possible values: h, v, hv
       */
    flip: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Convert image to jpg, pjpg, png, or webp.
       */
    fm: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Focal Point X. Specify a center point to focus on when cropping the image. Values from 0.0 to 1.0 in fractions of the image dimensions. (See crop)
       */
    fpX: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Focal Point Y. Specify a center point to focus on when cropping the image. Values from 0.0 to 1.0 in fractions of the image dimensions. (See crop)
       */
    fpY: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Height of the image in pixels. Scales the image to be that tall.
       */
    h: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Invert the image.
       */
    invert: {
        type: BooleanConstructor;
    };
    /**
       * Maximum height. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    maxH: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Maximum width. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    maxW: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Minimum height. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    minH: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Minimum width. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    minW: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Orientation. Possible values: 0, 90, 180 or 270.Rotate the image in 90 degree increments.
       */
    or: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Quality 0-100. Specify the compression quality (where applicable).
       */
    q: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Crop the image according to the provided coordinates (in pixel units of the source image).
       */
    rect: {
        type: StringConstructor;
    };
    /**
       * Saturation. Currently the asset pipeline only supports sat=-100, which renders the image with grayscale colors. Support for more levels of saturation is planned for later.
       */
    sat: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Sharpen 0-100.
       */
    sharpen: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Width of the image in pixels. Scales the image to be that wide.
       */
    w: {
        type: (StringConstructor | NumberConstructor)[];
    };
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}> | import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>[], unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, {}, string, import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    assetId: {
        type: StringConstructor;
        required: boolean;
    };
    projectId: {
        type: StringConstructor;
        default: null;
    };
    dataset: {
        type: StringConstructor;
        default: null;
    };
    /**
       * Set auto=format to automatically return an image in webp formatting if the browser supports it.
       */
    auto: {
        type: StringConstructor;
    };
    /**
       * Fill in any transparent areas in the image with a color. The string must be resolve to a valid hexadecimal color (RGB, ARGB, RRGGBB, or AARRGGBB). E.g. bg=ff00 for red background with no transparency.
       */
    bg: {
        type: StringConstructor;
    };
    /**
       * Blur 0-100.
       */
    blur: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: string | number) => boolean;
    };
    /**
         * Use with fit=crop to specify how cropping is performed:
            - top, bottom, left and right: The crop starts from the edge specified. crop=top,left will crop the image starting in the top left corner.
            - center: Will crop around the center of the image
            - focalpoint: Will crop around the focal point specified using the fp-x and fp-y parameters.
            - entropy: Attempts to preserve the "most important" part of the image by selecting the crop that preserves the most complex part of the image.
         */
    crop: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Configures the headers so that opening this link causes the browser to download the image rather than showing it. The browser will suggest to use the file name you provided.
       */
    dl: {
        type: StringConstructor;
    };
    /**
       * Specifies device pixel ratio scaling factor. From 1 to 3.
       */
    dpr: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
         * Affects how the image is handled when you specify target dimensions.
            - `clip`: The image is resized to fit within the bounds you specified without cropping or distorting the image.
            - `crop`: Crops the image to fill the size you specified when you specify both w and h
            - `fill`: Like clip, but the any free area not covered by your image is filled with the color specified in the bg parameter.
            - `fillmax`: Places the image within box you specify, never scaling the image up. If there is excess room in the image, it is filled with the color specified in the bg parameter.
            - `max`: Fit the image within the box you specify, but never scaling the image up.
            - `scale`: Scales the image to fit the constraining dimensions exactly. The resulting image will fill the dimensions, and will not maintain the aspect ratio of the input image.
            - `min`: Resizes and crops the image to match the aspect ratio of the requested width and height. Will not exceed the original width and height of the image.
         */
    fit: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Flipping. Flip image horizontally, vertically or both. Possible values: h, v, hv
       */
    flip: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Convert image to jpg, pjpg, png, or webp.
       */
    fm: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
       * Focal Point X. Specify a center point to focus on when cropping the image. Values from 0.0 to 1.0 in fractions of the image dimensions. (See crop)
       */
    fpX: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Focal Point Y. Specify a center point to focus on when cropping the image. Values from 0.0 to 1.0 in fractions of the image dimensions. (See crop)
       */
    fpY: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Height of the image in pixels. Scales the image to be that tall.
       */
    h: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Invert the image.
       */
    invert: {
        type: BooleanConstructor;
    };
    /**
       * Maximum height. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    maxH: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Maximum width. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    maxW: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Minimum height. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    minH: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Minimum width. Specifies size limits giving the backend some freedom in picking a size according to the source image aspect ratio.
       */
    minW: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Orientation. Possible values: 0, 90, 180 or 270.Rotate the image in 90 degree increments.
       */
    or: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Quality 0-100. Specify the compression quality (where applicable).
       */
    q: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Crop the image according to the provided coordinates (in pixel units of the source image).
       */
    rect: {
        type: StringConstructor;
    };
    /**
       * Saturation. Currently the asset pipeline only supports sat=-100, which renders the image with grayscale colors. Support for more levels of saturation is planned for later.
       */
    sat: {
        type: (StringConstructor | NumberConstructor)[];
    };
    /**
       * Sharpen 0-100.
       */
    sharpen: {
        type: (StringConstructor | NumberConstructor)[];
        validator: (value: unknown) => boolean;
    };
    /**
       * Width of the image in pixels. Scales the image to be that wide.
       */
    w: {
        type: (StringConstructor | NumberConstructor)[];
    };
}>>, {
    projectId: string;
    dataset: string;
    invert: boolean;
}, {}>;
export default _default;
